@@ -6,10 +6,11 @@ Views which should not have login protection go into :mod:`~integreat_cms.cms.ur
 from django.urls import include, path
 
 from ..forms import LanguageForm, OfferTemplateForm, OrganizationForm, RegionForm
-from ..models import Language, OfferTemplate, Organization, Role
+from ..models import Event, Language, OfferTemplate, Organization, Page, POI, Role
 
 from ..views import (
     analytics,
+    bulk_action_views,
     chat,
     dashboard,
     delete_views,
@@ -628,13 +629,17 @@ urlpatterns = [
                                                 [
                                                     path(
                                                         "download/",
-                                                        pages.download_xliff,
+                                                        pages.ExportXliffView.as_view(
+                                                            prefetch_translations=True
+                                                        ),
                                                         name="download_xliff",
                                                     ),
                                                     path(
                                                         "only-public/",
-                                                        pages.download_xliff,
-                                                        {"only_public": True},
+                                                        pages.ExportXliffView.as_view(
+                                                            only_public=True,
+                                                            prefetch_public_translations=True,
+                                                        ),
                                                         name="download_xliff_only_public",
                                                     ),
                                                     path(
@@ -652,9 +657,25 @@ urlpatterns = [
                                         ),
                                         path(
                                             "export/",
-                                            pages.export_pdf,
+                                            pages.GeneratePdfView.as_view(),
                                             name="export_pdf",
                                         ),
+                                        path(
+                                            "bulk-archive/",
+                                            bulk_action_views.BulkArchiveView.as_view(
+                                                model=Page,
+                                                archived_field="explicitly_archived",
+                                            ),
+                                            name="bulk_archive_pages",
+                                        ),
+                                        path(
+                                            "bulk-restore/",
+                                            bulk_action_views.BulkRestoreView.as_view(
+                                                model=Page,
+                                                archived_field="explicitly_archived",
+                                            ),
+                                            name="bulk_restore_pages",
+                                        ),
                                         path(
                                             "<int:page_id>/",
                                             include(
@@ -813,9 +834,25 @@ urlpatterns = [
                                         ),
                                         path(
                                             "auto-translate/",
-                                            events.automatic_translation,
+                                            bulk_action_views.BulkAutoTranslateView.as_view(
+                                                model=Event
+                                            ),
                                             name="automatic_translation_events",
                                         ),
+                                        path(
+                                            "bulk-archive/",
+                                            bulk_action_views.BulkArchiveView.as_view(
+                                                model=Event
+                                            ),
+                                            name="bulk_archive_events",
+                                        ),
+                                        path(
+                                            "bulk-restore/",
+                                            bulk_action_views.BulkRestoreView.as_view(
+                                                model=Event
+                                            ),
+                                            name="bulk_restore_events",
+                                        ),
                                         path(
                                             "<int:event_id>/",
                                             include(
@@ -880,9 +917,25 @@ urlpatterns = [
                                         ),
                                         path(
                                             "auto-translate/",
-                                            pois.automatic_translation,
+                                            bulk_action_views.BulkAutoTranslateView.as_view(
+                                                model=POI
+                                            ),
                                             name="automatic_translation_pois",
                                         ),
+                                        path(
+                                            "bulk-archive/",
+                                            bulk_action_views.BulkArchiveView.as_view(
+                                                model=POI
+                                            ),
+                                            name="bulk_archive_pois",
+                                        ),
+                                        path(
+                                            "bulk-restore/",
+                                            bulk_action_views.BulkRestoreView.as_view(
+                                                model=POI
+                                            ),
+                                            name="bulk_restore_pois",
+                                        ),
                                         path(
                                             "<int:poi_id>/",
                                             include(
